%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Background Correction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [signal,reference]=bkg_correction;

global Sig Ref n_s n_r number_1 number_2 signal reference bkg_signal bkg_reference Column MetaColumn Row MetaRow n_mrow n_mcol n_row n_col pos1 pos2

disp(' ')
disp('Background Correction:')
disp(' ')
disp(' 1 : Background substraction.')
disp(' 2 : No correction.')
disp(' ')
choice = input(' - choose method [2]: ');

if isempty(choice), choice=2; end;

n_g = size(Sig(1,1).SignMed,1);

signal = ones(n_g,n_s*n_r);
reference = ones(n_g,n_s*n_r);
bkg_signal = ones(n_g,n_s*n_r);
bkg_reference = ones(n_g,n_s*n_r);

switch choice
case 1
    for s=1:n_s,
        for r=1:n_r,
            index = r + n_r*(s-1); % index for columns in matrix densities.
            signal(:,index) = Sig(s,r).SignMed-Sig(s,r).BackMed;
            reference(:,index) = Ref(s,r).SignMed-Ref(s,r).BackMed;
            bkg_signal(:,index)= Sig(s,r).BackMed;
            bkg_reference(:,index)= Ref(s,r).BackMed;
        end;
    end;
    
    disp(' - background substraction.')
    disp(' ')
    disp(' - Note: neg. values replaced by NaN')
    % ******************* Replace negative values ***************************************
    [n_g,n_a] = size(signal);
    
    for i=1:n_a
        counts=0;
        for j=1:n_g,
            if (reference(j,i) <= 0)|(signal(j,i) <= 0),
                reference(j,i) = NaN;
                signal(j,i) = NaN;
                counts = counts+1;
            end;
        end;
        disp(['    Array ',int2str(i),' : ',int2str(counts),' replacements of NaN for values <= 0.'])    
    end;
    
%     for i=1:n_a,      %for each array
%         dummy = ~isnan(signal(:,i)); % produces a vector with ones for finite numbers.
%         indices = find(dummy);      % returns indices to spots with finite value.
%         dummy = signal(indices,i); % extract finite values.
%         dummy1 = dummy(find(dummy > 0)); % extract positive values.
%         min_val_s = min(dummy1); % this is the smallest positive value in the array.
%         
%         dummy = ~isnan(reference(:,i)); % produces a vector with ones for finite numbers.
%         indices = find(dummy);      % returns indices to spots with finite value.
%         dummy = reference(indices,i); % extract finite values.
%         dummy1 = dummy(find(dummy > 0)); % extract positive values.
%         min_val_r = min(dummy1); % this is the smallest positive value in the array.
%         
%         count_s = 0; % counts the number of replacements.
%         count_r = 0;
%         for j=1:n_g,
%             if reference(j,i) <= 0,
%                 reference(j,i) = min_val_r;
%                 count_r = count_r+1;
%             end;
%             if signal(j,i) <= 0,
%                 signal(j,i) = min_val_s;
%                 count_s = count_s+1;
%             end;
%             % This has replaced all values <= zero.
%         end;
%         disp(['    Array ',int2str(i),' : Sig. ',int2str(count_s),' Ref. ',...
%                 int2str(count_s),' replacements for values <= 0.'])
%     end;  
case 2
    for s=1:n_s,
        for r=1:n_r,
            index = r + n_r*(s-1); % index for columns in matrix densities.
            signal(:,index) = Sig(s,r).SignMed;
            reference(:,index) = Ref(s,r).SignMed;
            bkg_signal(:,index)= Sig(s,r).BackMed;
            bkg_reference(:,index)= Ref(s,r).BackMed;
        end;
    end;  
    
    disp('No correction');
    
    disp(' ')
    disp('Note: Data now stored in variables:')
    disp(' - signal')
    disp(' - reference')
end;

disp(' ');
choice = input(' - contour plots ?  (Y/N) [N] : ','s');
if isempty(choice), choice = 'N'; end;
if strcmp('y',choice) | strcmp('Y',choice),
    decision = 'Y';
    while strcmp('Y',decision) | strcmp('y',decision),      
        
        disp(' ')
        s = input([' - ',number_1,'    : ']);
        r = input([' - ',number_2,'    : ']);
        
        index = r + n_r*(s-1);
        sig_sig=signal(:,index);
        sig_bkg=bkg_signal(:,index);
        ref_sig=reference(:,index);
        ref_bkg=bkg_reference(:,index);
        
        
        con_sig_sig = NaN.*ones(n_mrow*n_row,n_mcol*n_col);
        con_ref_sig = NaN.*ones(n_mrow*n_row,n_mcol*n_col);
        for spot=1:n_g;        
            x(spot) = Column(spot) + (MetaColumn(spot)-1)*(n_col); %calculates de x coordenate for the image position
            y(spot) = Row(spot) + (MetaRow(spot)-1)*(n_col);       %calculates de y coordenate for the image position
            con_sig_sig(y(spot),x(spot)) = sig_sig(spot);        %creates a new matrix with the new coordenates
            con_ref_sig(y(spot),x(spot)) = ref_sig(spot);
        end;
        
        con_sig_bkg = NaN.*ones(n_mrow*n_row,n_mcol*n_col);
        con_ref_bkg = NaN.*ones(n_mrow*n_row,n_mcol*n_col);
        for spot=1:n_g;        
            x(spot) = Column(spot) + (MetaColumn(spot)-1)*(n_col); %calculates de x coordenate for the image position
            y(spot) = Row(spot) + (MetaRow(spot)-1)*(n_col);       %calculates de y coordenate for the image position
            con_sig_bkg(y(spot),x(spot)) = sig_bkg(spot);        %creates a new matrix with the new coordenates
            con_ref_bkg(y(spot),x(spot)) = ref_bkg(spot);
        end;
        
        figure('Position',pos1);
        subplot(1,2,1);
        dummy=con_sig_bkg;
        size(dummy)
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn), 20);axis('image');
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('signal bkg');
        
        subplot(1,2,2);
        dummy=con_ref_bkg;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn), 20);axis('image'); 
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('reference bkg');
        
        figure('Position',pos1);
        subplot(1,2,1);
        dummy=con_sig_sig;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn), 20);axis('image');
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('signal signal');
        
        subplot(1,2,2);
        dummy=con_ref_sig;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn), 20);axis('image'); 
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('reference signal');
        
        figure('Position',pos2);
        subplot(1,2,1);
        dummy = con_ref_bkg ./ con_sig_bkg;
        %dummy = con_sig_sig ./ con_ref_sig;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn),20);axis('image');
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('bkg ref / bkg sig');
        
        subplot(1,2,2);
        dummy = con_ref_sig ./ con_sig_sig;
        %dummy = con_sig_sig ./ con_ref_sig;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn),20);axis('image');
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('ref sig / sig sig');
        
        figure('Position',pos2);
        dummy = (con_ref_sig./con_ref_bkg) ./ (con_sig_sig./con_sig_bkg);
        %dummy = con_sig_sig ./ con_ref_sig;
        %dummy(~isnan(dummy)) = log2(dummy(~isnan(dummy)));
        [Yn val c_map]=h_color(dummy);
        contourf(flipud(Yn),20);axis('image');
        colormap(c_map);
        colorbar('horiz');
        set(gca,'FontSize',8);title('ref/bkg ref / sig/bkg sig');
        
    
    disp(' ')
    decision = input(' - another sample? (Y/N) [N] : ','s');
    if isempty(decision), decison = 'N'; end;
end; % of while loop. 
end;




