%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Flag Handling
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ImaGene V.4.1 :
%
% Flag:     Definition:                             Set if...
%
% 0         No flag                                                              
% 1         Manual flag (no type)                                
% 2         Automatic flag for an empty spot        Set if (mean signal - mean bkg) / std background < threshold
% 3         Automatic flag for a poor spot          Set if (std of signal / mean of signal) > threshold
% 4         Automatic flag for a negative spot      Set if (background mean > signal mean)
% 5         Manual flag for an empty spot           (for spots that are not distinguishable from background)         
% 6         Manual flag for a poor spot             (for low-quality spots)         
% 7         Manual falg for a negative spot         (for spots where signal mean is lower than background mean)     

% Interpretation for Matlab analysis:
%
% Flag:     Definition:                             Action:
%
% 0         No flag                                 No                              
% 1         Manual flag (no type)                   Replace with NaN                
% 2         Automatic flag for an empty spot        No.   
% 3         Automatic flag for a poor spot          No.
% 4         Automatic flag for a negative spot      No.
% 5         Manual flag for an empty spot           No
% 6         Manual flag for a poor spot             Replace with NaN
% 7         Manual flag for a negative spot         No

% Note: Flags 2 and 3 for automatic poor and empty spots rely on a threshold set by the user (in ImaGene).

function flag_handling;

global Sig Ref GeneId n_s n_r number_1 number_2 Column

disp(' ')
disp('Flag Handling:')
disp(' ')
disp(' Flags: ')
disp(' ')
disp(' 0 No flag')                                                              
disp(' 1 Manual flag (no type)')                               
disp(' 2 Autom. flag empty spot             Set if (mean sig - mean bkg) / std bkg < thresh.')
disp(' 3 Autom. flag poor spot               Set if (std of sig / mean of sig) > threshold ')
disp(' 4 Autom. flag negative spot         Set if (background mean > signal mean)')
disp(' 5 Manual flag empty spot            For spots that are not disting. from bkg.')         
disp(' 6 Manual flag for a poor spot      For low-quality spots')       
disp(' 7 Manual falg for a neg. spot      For spots where signal mean is < bkg mean')
disp(' ')

n_g=size(Column,1);
flagging=0;

choice = input(' - Aditional flagging ? (Y/N) [N] : ','s');
if isempty(choice), choice = 'N'; end;

if strcmp('y',choice) | strcmp('Y',choice),
    flagging=1;
    
    disp(' ');
    disp(' Flags for each channel:');
    disp(' ');
    disp(' 8    No flag');                                                              
    disp(' 9    Signal Median < Z* Background Median');                               
    disp(' ');
    Z = input('    Z  [5] : ');
    if isempty(Z), Z = 5; end;

    for s=1:n_s;
        for r=1:n_r;
            for i=1:n_g;
                
                if Sig(s,r).SignMed(i)>Z*Sig(s,r).BackMed(i);
                    Sig(s,r).Flag_set(i,1)=8;
                else 
                    Sig(s,r).Flag_set(i,1)=9;
                end;
                if Ref(s,r).SignMed(i)>Z*Ref(s,r).BackMed(i);
                    Ref(s,r).Flag_set(i,1)=8;
                else
                    Ref(s,r).Flag_set(i,1)=9;
                end;
                
            end;
        end;
    end;
    
end;

disp(' ');
choice = input(' - do you want a flag report? (Y/N) [N] : ','s');
if isempty(choice), choice = 'N'; end;
if strcmp('y',choice) | strcmp('Y',choice),
    
switch flagging
case 0
    for s = 1:n_s;   
        for r = 1:n_r;
            disp(' ');
            disp([number_1,' ',int2str(s),',',number_2,' ',int2str(r)]);
            dummy = find(Sig(s,r).Flag == 1);
            num_flags=size(dummy,1);
            disp(['Flag 1: '  int2str(num_flags)]);
            F(s,r).f1=dummy;
            
            dummy = find(Sig(s,r).Flag == 2);
            num_flags=size(dummy,1);
            disp(['Flag 2: ' int2str(num_flags)]);
            F(s,r).f2=dummy;
            
            dummy = find(Sig(s,r).Flag == 3);
            num_flags=size(dummy,1);
            disp(['Flag 3: ' int2str(num_flags)]);
            F(s,r).f3=dummy;
            
            dummy = find(Sig(s,r).Flag == 4);
            num_flags=size(dummy,1);
            disp(['Flag 4: ' int2str(num_flags)]);
            F(s,r).f4=dummy;
            
            dummy = find(Sig(s,r).Flag == 5);
            num_flags=size(dummy,1);
            disp(['Flag 5: ' int2str(num_flags)]);
            F(s,r).f5=dummy;
            
            dummy = find(Sig(s,r).Flag == 6);
            num_flags=size(dummy,1);
            disp(['Flag 6: ' int2str(num_flags)]);
            F(s,r).f6=dummy;
            
            dummy = find(Sig(s,r).Flag == 7);
            num_flags=size(dummy,1);
            disp(['Flag 7: ' int2str(num_flags) ]);
            F(s,r).f7=dummy;
        end;
    end;
    
    disp(' ');
    disp (' NaN Replacements:');
    disp(' ')
    disp(' - check for flags: 1,6')
    disp(' - replace with NaN (Not a Number)')  
    
    dflag = 0; % flag to find case where no genes are replaced.
    for s = 1:n_s;   
        for r = 1:n_r;
            % Note: we test for flags referring to the 'signal', assuming that the 'reference' has the same flag.
            dummy1 = find(Sig(s,r).Flag == 1 ); 
            dummy3 = []; 
            dummy6 = find(Sig(s,r).Flag == 6 );
            if ~isempty(dummy1),
                dflag = 1;
                Sig(s,r).SignMed(dummy1) = NaN;
                Sig(s,r).BackMed(dummy1) = NaN;
                Ref(s,r).SignMed(dummy1) = NaN;
                Ref(s,r).BackMed(dummy1) = NaN;
                num_flags=size(dummy1,1);
                disp([number_1,' ',int2str(s),' ',number_2,' ',int2str(r),'    Flag 1 :   ', int2str(num_flags) ]);
            end;
            if ~isempty(dummy3),
                dflag = 1;
                Sig(s,r).SignMed(dummy3) = NaN;
                Sig(s,r).BackMed(dummy3) = NaN;
                Ref(s,r).SignMed(dummy3) = NaN;
                Ref(s,r).BackMed(dummy3) = NaN;
                num_flags=size(dummy3,1);
                disp([number_1,' ',int2str(s),' ',number_2,' ',int2str(r),'    Flag 3 :   ', int2str(num_flags)]);
            end;
            if ~isempty(dummy6),
                dflag = 1;
                Sig(s,r).SignMed(dummy6) = NaN;
                Sig(s,r).BackMed(dummy6) = NaN;
                Ref(s,r).SignMed(dummy6) = NaN;
                Ref(s,r).BackMed(dummy6) = NaN;
                num_flags=size(dummy6,1);
                disp([number_1,' ',int2str(s),' ',number_2,' ',int2str(r),'    Flag 6 :   ', int2str(num_flags)]);
            end;
        end;
    end;
    disp(' ');
    if dflag == 0; disp(' - there were no NaN replacements in flags 1 and 6.'); end;
    
case 1   
      for s = 1:n_s;   
        for r = 1:n_r;
            disp(' ');
            disp([number_1,' ',int2str(s),',',number_2,' ',int2str(r)]);
            dummy = find(Sig(s,r).Flag == 1);
            num_flags=size(dummy,1);
            disp(['Flag 1: '  int2str(num_flags)]);
            F(s,r).f1=dummy;
            
            dummy = find(Sig(s,r).Flag == 2);
            num_flags=size(dummy,1);
            disp(['Flag 2: ' int2str(num_flags)]);
            F(s,r).f2=dummy;
            
            dummy = find(Sig(s,r).Flag == 3);
            num_flags=size(dummy,1);
            disp(['Flag 3: ' int2str(num_flags)]);
            F(s,r).f3=dummy;
            
            dummy = find(Sig(s,r).Flag == 4);
            num_flags=size(dummy,1);
            disp(['Flag 4: ' int2str(num_flags)]);
            F(s,r).f4=dummy;
            
            dummy = find(Sig(s,r).Flag == 5);
            num_flags=size(dummy,1);
            disp(['Flag 5: ' int2str(num_flags)]);
            F(s,r).f5=dummy;
            
            dummy = find(Sig(s,r).Flag == 6);
            num_flags=size(dummy,1);
            disp(['Flag 6: ' int2str(num_flags)]);
            F(s,r).f6=dummy;
            
            dummy = find(Sig(s,r).Flag == 7);
            num_flags=size(dummy,1);
            disp(['Flag 7: ' int2str(num_flags) ]);
            F(s,r).f7=dummy;
            
            disp('Signal:')
            dummy = find(Sig(s,r).Flag_set == 8);
            num_flags=size(dummy,1);
            disp(['Flag 8: ' int2str(num_flags) ]);                
            dummy = find(Sig(s,r).Flag_set == 9);
            num_flags=size(dummy,1);
            disp(['Flag 9: ' int2str(num_flags) ]);
            disp('Reference: ');
            dummy = find(Ref(s,r).Flag_set == 8);
            num_flags=size(dummy,1);
            disp(['Flag 8: ' int2str(num_flags) ]);
            dummy = find(Ref(s,r).Flag_set == 9);
            num_flags=size(dummy,1);
            disp(['Flag 9: ' int2str(num_flags) ]);
        end;
    end;
    
    disp(' ');
    disp (' NaN Replacements:');
    disp(' ')
    disp(' - check for flags: 1,6 and Z flags')
    disp(' - replace with NaN (Not a Number)')
    
    for s = 1:n_s;   
        for r = 1:n_r;
            tot_sig=0;
            tot_ref=0;
            dummy = find(Sig(s,r).Flag_set == 8 ); 
            tot_sig=size(dummy,1)+tot_sig;
            if ~isempty(dummy),
                Sig(s,r).SignMed(dummy) = NaN;
                Sig(s,r).BackMed(dummy) = NaN;     
            end;
            dummy = find(Ref(s,r).Flag_set == 9 ); 
            tot_ref=size(dummy,1)+tot_ref;
            if ~isempty(dummy),
                Ref(s,r).SignMed(dummy) = NaN;
                Ref(s,r).BackMed(dummy) = NaN;              
            end;
        end;
    end;
     disp(' ');
    disp([' - there were ',int2str(tot_sig),' Signal NaN replacements in flag Z.']); 
    disp([' - there were ',int2str(tot_ref),' Reference NaN replacements in flag Z.']);
end;

end; %end case