% Analysis of Tuberculosis microarray data set, provided by St. George's Hospital London.
%
% TB 10-00
%
% The time course experiments consistes of four time points and four replicates.
%
% ImaGene Header for 1st sample, 1st replicate, reference (Cy5 - genomic DNA):
%
% Begin Header
% 	version	4.1
% 	Date	Fri May 18 13:04:15 GMT+01:00 2001
% 	Image File	C:\My Documents\Transferred\TB3\TB3_42_Cy5_1.tif
% 	Inverted	false
% 	Begin Field Dimensions
% 		Field	Metarows	Metacols	Rows	Cols
% 		TB	4	4	17	17
% 	End Field Dimensions
% 	Begin Measurement parameters
% 		Segmentation Method	fixed circle
% 		Signal Low	0.05
% 		Signal High	0.95
% 		Background Low	0.0
% 		Background High	0.9
% 		Background Buffer	3.0
% 		Background Width	5.0
% 	End Measurement parameters
% End Header
%
%Swapping of dyes
%
%SAMPLE      REPLICATE    DYE(signal Cy3 or 5)
%     1               1                   3
%     1               2                   3
%     1               3                   3
%     1               4                   5
%     2               1                   3
%     2               2                   3
%     2               3                   3
%     2               4                   5
%     3               1                   3
%     3               2                   3
%     3               3                   5
%     3               4                   3
%     4               1                   3
%     4               2                   3
%     4               3                   3
%     4               4                   5
    

% Note: V.4.2 of ImaGene contains threshold information for flags.

clc
clear all
clear global GeneId genome Sig Ref signal reference bkg_signal bkg_reference number_1 number_2 n_s n_r n_mrow n_mcol n_row n_col Column MetaColumn Row MetaRow time X  XX index X_cluster l_sig l_ref l_exp l_uni pos1 pos2 pos3 pos4 pos5 pos6 f_hndl_1 f_hndl_2 F

% "Global" variables (fixed throughout this script file:
global GeneId genome Sig Ref signal reference bkg_signal bkg_reference number_1 number_2 n_s n_r n_mrow n_mcol n_row n_col Column MetaColumn Row MetaRow time X XX index X_cluster l_sig l_ref l_exp l_uni pos1 pos2 pos3 pos4 pos5 pos6 f_hndl_1 f_hndl_2 F

[genome] = textread('Ordered_genome_description.txt','%s','delimiter','\n');
time = [6;14;20;30];    % measured time points in days.
n_s  = 4;               % number of samples (time points).
n_r  = 4;               % number of replicates.
n_mrow = 4;               % number of metarows.
n_mcol = 4;               % number of metacolumns.
n_row = 17;             % number of rows.
n_col = 17;             % number of columns.

% Labels that can be used in plots:
l_sig = 'RNA';       
l_ref = 'DNA';
l_exp = 'TB 10-00';
l_uni = '[days]';
number_1= 'Sample';
number_2= 'Replicate';

% Create positions for two figures occupying the upper half of the screen:
bdwidth = 5; topbdwidth = 30;
set(0,'Units','pixels') 
scnsize = get(0,'ScreenSize'); % left bottom width height
% Upper left corner:
pos1 = [bdwidth, ...
      scnsize(4)/2+0.5*topbdwidth+bdwidth, ...
      scnsize(3)/2 - 2*bdwidth, ...
      scnsize(4)/2-3*topbdwidth];
% Upper right corner:      
pos2 = [pos1(1) + scnsize(3)/2, ...
      scnsize(4)/2+0.5*topbdwidth+bdwidth, ...
      pos1(3), ...
      scnsize(4)/2-3*topbdwidth];
% Lower right corner:     
pos3 = [pos1(1) + scnsize(3)/2, ...
      topbdwidth + bdwidth, ...
      pos1(3), ...
      scnsize(4)/2 - 3*topbdwidth];
% Lower left corner:
pos4 = [pos1(1), ...
        topbdwidth + bdwidth, ...
        scnsize(3)/2 - 2*bdwidth, ...
        scnsize(4)/2 - 3*topbdwidth];
% Large figure top-to-bottom on the left:
pos5 = [bdwidth, ...
      topbdwidth + bdwidth, ...
      scnsize(3)/2 - 2*bdwidth, ...
      scnsize(4)-3*topbdwidth-3*bdwidth];
% Large figure top-to-bottom on the right:
pos6 = [pos1(1) + scnsize(3)/2, ...
      topbdwidth + bdwidth, ...
      scnsize(3)/2 - 2*bdwidth, ...
      scnsize(4)-3*topbdwidth-3*bdwidth];
disp(' ');
disp('MADE:  Microarray Data Explorer');
disp(' ')
disp('Data: ');
disp(' ');
disp('TB 10-00: St Georges Hospital')
disp(' ')
disp(' - median intensity values loaded for further analysis.')
disp([' - Signal channel   : ',l_sig ])    
disp([' - Reference channel: ',l_ref ])
